@@ -114,7 +114,7 @@ add.interval.col <- function(name,
       choices=c(
         "unitless", "fraction", "%", "count",
         "time", "inverse_time",
-        "amount",
+        "amount", "amount_dose",
         "conc", "conc_dosenorm",
         "dose",
         "volume",
@@ -252,4 +252,4 @@ add.interval.col(
   unit_type="time",
   pretty_name="Interval End",
   desc = "Ending time of the interval (potentially infinity)"
-)
\ No newline at end of file
+)
