@@ -34,3 +34,10 @@
 
 # To work with the use of dplyr's pipe within the exclude function
 utils::globalVariables(".")
+
+.onLoad <- function(...) {
+  if (requireNamespace("units", quietly = TRUE)) {
+    # Allow "fraction" to be used as a unit for fraction excreted
+    units::install_unit(symbol = "fraction", def = "1")
+  }
+}
