@@ -1,19 +1,18 @@
 #' Determine time at or above a set value
 #'
-#' Interpolation is performed aligning with \code{PKNCA.options("auc.method")}.
+#' Interpolation is performed aligning with `PKNCA.options("auc.method")`.
 #' Extrapolation outside of the measured times is not yet implemented.  The
-#' \code{method} may be changed by giving a named \code{method} argument, as
-#' well.
+#' `method` may be changed by giving a named `method` argument, as well.
 #'
-#' For \code{'lin up/log down'}, if \code{clast} is above \code{conc_above} and
-#' there are concentrations BLQ after that, linear down is used to extrapolate
-#' to the BLQ concentration (equivalent to AUCall).
+#' For `'lin up/log down'`, if `clast` is above `conc_above` and there are
+#' concentrations BLQ after that, linear down is used to extrapolate to the BLQ
+#' concentration (equivalent to AUCall).
 #'
 #' @inheritParams pk.calc.auxc
 #' @param conc_above The concentration to be above
 #' @param ... Extra arguments.  Currently, the only extra argument that is used
-#'   is \code{method} as described in the details section.
-#' @return the time above the given concentration
+#'   is `method` as described in the details section.
+#' @returns the time above the given concentration
 #' @export
 pk.calc.time_above <- function(conc, time,
                                conc_above,
@@ -33,7 +32,7 @@ pk.calc.time_above <- function(conc, time,
   stopifnot("conc_above must not be NA"=!is.na(conc_above))
   stopifnot("conc_above must be numeric"=is.numeric(conc_above))
   if (check) {
-    check.conc.time(conc, time)
+    assert_conc_time(conc = conc, time = time)
   }
   # Only keep evaluable rows
   data <- data.frame(conc=conc, time=time)[!is.na(conc), , drop=FALSE]
