@@ -72,6 +72,7 @@ test_that("pk.calc.half.life", {
                           r.squared=0.9999999,
                           adj.r.squared=0.9999999,
                           lambda.z.time.first=0,
+                          lambda.z.time.last=3,
                           lambda.z.n.points=4,
                           clast.pred=0.12507,
                           half.life=1.000346,
@@ -89,6 +90,7 @@ test_that("pk.calc.half.life", {
                           r.squared=0.9999999,
                           adj.r.squared=0.9999999,
                           lambda.z.time.first=0,
+                          lambda.z.time.last=3,
                           lambda.z.n.points=4,
                           clast.pred=0.12507,
                           half.life=1.000346,
@@ -106,6 +108,7 @@ test_that("pk.calc.half.life", {
                           r.squared=0.9999999,
                           adj.r.squared=0.9999999,
                           lambda.z.time.first=0,
+                          lambda.z.time.last=3,
                           lambda.z.n.points=4,
                           clast.pred=0.12507,
                           half.life=1.000346,
@@ -178,6 +181,7 @@ test_that("half-life manual point selection", {
       r.squared = 1,
       adj.r.squared = 1,
       lambda.z.time.first = 1L,
+      lambda.z.time.last = 3L,
       lambda.z.n.points = 3L,
       clast.pred = 8,
       half.life = -1,
@@ -207,6 +211,7 @@ test_that("two-point half-life succeeds (fix #114)", {
         r.squared=1,
         adj.r.squared=NA_real_,
         lambda.z.time.first=0,
+        lambda.z.time.last=1,
         lambda.z.n.points=2,
         clast.pred=0.5,
         half.life=1,
@@ -220,10 +225,98 @@ test_that("two-point half-life succeeds (fix #114)", {
   )
 })
 
+test_that("When tlast is excluded, lambda.z.time.last != tlast", {
+  d_conc <- data.frame(
+    conc = c(1, 0.5, 0.25, 0.1251, 0.05, 0),
+    time = c(0, 1, 2, 3, 4, 5),
+    exclude_hl = c(FALSE, FALSE, FALSE, FALSE, TRUE, FALSE),
+    subject = 1
+  )
+  d_dose <- data.frame(dose = 1, time = 0, subject = 1)
+
+  o_conc <- PKNCAconc(d_conc, formula = conc ~ time | subject, exclude_half.life = "exclude_hl")
+  o_dose <- PKNCAdose(d_dose, formula = dose ~ time | subject)
+  o_data <- PKNCAdata(o_conc, o_dose)
+  myresult <- pk.nca(o_data)
+  expect_equal(
+    myresult$result[myresult$result$PPTESTCD == "lambda.z.time.last",]$PPORRES,
+    3
+  )
+})
+
+
+test_that("lambda.z.time.first is after the absorption phase in infusion studies (shifts with duration)", {
+  # Simulate an infusion with two different durations
+  d_conc <- data.frame(
+    conc = c(0.5, 1.0, 0.5, 0.12, 0.25, 0.05),
+    time = 1:6,
+    subject = 1
+  )
+  d_dose <- data.frame(
+    dose = 1,
+    time = 0,
+    duration1 = 2,  # Duration for case 1
+    duration2 = 3,  # Duration for case 2
+    route = "intravascular",
+    subject = 1
+  )
+
+  # First case: duration = 2, so lambda.z.time.first should be after 2
+  o_data1 <- PKNCAdata(
+    PKNCAconc(d_conc, conc ~ time | subject),
+    PKNCAdose(d_dose, dose ~ time | subject, route = "route", duration = "duration1"),
+    intervals = data.frame(start = 0, end = Inf, half.life = TRUE)
+  )
+  res1 <- pk.nca(o_data1)
+  lz_first1 <- res1$result$PPORRES[res1$result$PPTESTCD == "lambda.z.time.first"]
+  expect_equal(lz_first1, 3)
+
+  # Second case: duration = 4, so lambda.z.time.first should be after 3
+  o_data2 <- PKNCAdata(
+    PKNCAconc(d_conc, conc ~ time | subject),
+    PKNCAdose(d_dose, dose ~ time | subject, route = "route", duration = "duration2"),
+    intervals = data.frame(start = 0, end = Inf, half.life = TRUE)
+  )
+  res2 <- pk.nca(o_data2)
+  lz_first2 <- res2$result$PPORRES[res2$result$PPTESTCD == "lambda.z.time.first"]
+  expect_equal(lz_first2, 4)
+
+  # And the second case should be later than the first
+  expect_true(lz_first2 > lz_first1)
+})
+
+test_that("for an interval with multiple doses lambda.z is calculated for the latest one", {
+  # Simulate two infusions: one at time 0 (duration 2), one at time 4 (duration 2)
+  d_conc <- data.frame(
+    conc = c(0.5, 1.0, 0.99, 0.98, 0.97, 0.96,
+             0.5, 1.0, 0.8, 0.5, 0.2, 0.1),
+    time = 1:12,
+    subject = 1
+  )
+  d_dose <- data.frame(
+    dose = c(1, 1),
+    time = c(6, 0),
+    duration = c(2, 2),
+    route = "intravascular",
+    subject = 1
+  )
+  o_data <- PKNCAdata(
+    PKNCAconc(d_conc, conc ~ time | subject),
+    PKNCAdose(d_dose, dose ~ time | subject, route = "route", duration = "duration"),
+    intervals = data.frame(start = c(0, 0, 6),
+                           end = c(Inf, 6, 12),
+                           half.life = TRUE)
+  )
+  res <- pk.nca(o_data)
+  lzs <- res$result$PPORRES[res$result$PPTESTCD == "lambda.z"]
+  # Lambda z for the first interval (0 to Inf) should be the same as for the third interval (6 to 12)
+  expect_equal(lzs[1], lzs[3])
+})
+
 test_that("get_halflife_points", {
   o_conc <- PKNCAconc(Theoph, conc~Time|Subject)
   o_data <- PKNCAdata(o_conc, intervals = data.frame(start = 0, end = Inf, half.life = TRUE))
-  o_nca <- pk.nca(o_data)
+  o_nca <- suppressMessages(pk.nca(o_data))
   hl_points <- suppressMessages(get_halflife_points(o_nca))
 
   # Visualize the results
@@ -309,4 +402,34 @@ test_that("get_halflife_points", {
     suppressMessages(get_halflife_points(o_nca)),
     regexp = "More than one half-life calculation was attempted on the following rows: 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11"
   )
+
+  # Half-life points are selected right even if lambda.z.time.last != tlast (#448)
+  d_conc <- data.frame(
+    conc = c(1, 0.5, 0.25, 0.125, 0.07, 0, 0.01),
+    time = c(0, 1, 2, 3, 4, 5, 6),
+    exclude_hl = c(FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE),
+    subject = 1
+  )
+  # without exclusion of Tlast
+  o_conc <- PKNCAconc(d_conc, formula = conc ~ time | subject)
+  o_data <- PKNCAdata(o_conc, intervals = data.frame(start = 0, end = Inf, half.life = TRUE))
+  o_nca <- suppressMessages(pk.nca(o_data))
+  hl_points <- suppressMessages(get_halflife_points(o_nca))
+  # Note that BLQ times are included
+  expect_equal(
+    d_conc$time[which(hl_points)],
+    1:6,
+    info = "get_halflife_points uses lambda.z.time.last, not tlast"
+  )
+  # with exclusion of Tlast
+  o_conc <- PKNCAconc(d_conc, formula = conc ~ time | subject, exclude_half.life = "exclude_hl")
+  o_data <- PKNCAdata(o_conc, intervals = data.frame(start = 0, end = Inf, half.life = TRUE))
+  o_nca <- suppressMessages(pk.nca(o_data))
+  hl_points <- suppressMessages(get_halflife_points(o_nca))
+  # lambda.z.time.last should be 4, tlast is 6 and excluded
+  expect_equal(
+    d_conc$time[which(hl_points)],
+    1:4,
+    info = "get_halflife_points uses lambda.z.time.last, not tlast"
+  )
 })
